@@ -10,7 +10,6 @@ from ..feature import set
 from ..artefacts.library import library
 from ..tools.compiler import link
 from ..tools.python import python
-from ..types import pyd
 from os.path import join, normpath
 
 
@@ -21,13 +20,9 @@ class extension(library):
         p = python.instance(self.features)
         self.features |= set(p.include, p.linkpath, link('shared'))
         self.features |= p.libs(condition=(set.cc.name=='msvc')|(set.cxx.name=='msvc'))
+        self._suffix = p.ext_suffix
 
     @property
     def _filename(self):
-        host = str(self.features.target.os) if 'target' in self.features else ''
-        # Note: `pyd` is only used to compute the filename,
-        #       not as the artefact's type.
-        #       This is because as far as tools (and implicit rules)
-        #       are concerned, a Python extension is a dso...
-        libname = pyd.synthesize_name(self.name, host)
+        libname = self.name + self._suffix
         return normpath(join(self.module.builddir, self.relpath, libname))
