@@ -117,4 +117,8 @@ class python(tool):
         flags += ' ' + self.check_sysconfig('get_config_var("SHLIBS")')
         flags = [f[2:] for f in flags.strip().split() if f.startswith('-l')]
         self.libs += libs(*flags)
-        self.ext_suffix = self.check_sysconfig('get_config_var("EXT_SUFFIX")')
+        version = self.check_python('import sys; print(sys.version_info[:2])')
+        if version >= '3.5':
+            self.ext_suffix = self.check_sysconfig('get_config_var("EXT_SUFFIX")')
+        else:
+            self.ext_suffix = self.check_sysconfig('get_config_var("SO")')
